==> opencv-4.10.0-10.gpkg.tar: image/usr/lib64/cmake/opencv4/OpenCVModules-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "opencv_core" for configuration "RelWithDebInfo"
set_property(TARGET opencv_core APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(opencv_core PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libopencv_core.so.4.10.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libopencv_core.so.410"
  )

list(APPEND _cmake_import_check_targets opencv_core )
list(APPEND _cmake_import_check_files_for_opencv_core "${_IMPORT_PREFIX}/lib64/libopencv_core.so.4.10.0" )

# Import target "opencv_flann" for configuration "RelWithDebInfo"
set_property(TARGET opencv_flann APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(opencv_flann PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libopencv_flann.so.4.10.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libopencv_flann.so.410"
  )

list(APPEND _cmake_import_check_targets opencv_flann )
list(APPEND _cmake_import_check_files_for_opencv_flann "${_IMPORT_PREFIX}/lib64/libopencv_flann.so.4.10.0" )

# Import target "opencv_imgproc" for configuration "RelWithDebInfo"
set_property(TARGET opencv_imgproc APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(opencv_imgproc PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libopencv_imgproc.so.4.10.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libopencv_imgproc.so.410"
  )

list(APPEND _cmake_import_check_targets opencv_imgproc )
list(APPEND _cmake_import_check_files_for_opencv_imgproc "${_IMPORT_PREFIX}/lib64/libopencv_imgproc.so.4.10.0" )

# Import target "opencv_ml" for configuration "RelWithDebInfo"
set_property(TARGET opencv_ml APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(opencv_ml PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libopencv_ml.so.4.10.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libopencv_ml.so.410"
  )

list(APPEND _cmake_import_check_targets opencv_ml )
list(APPEND _cmake_import_check_files_for_opencv_ml "${_IMPORT_PREFIX}/lib64/libopencv_ml.so.4.10.0" )

# Import target "opencv_photo" for configuration "RelWithDebInfo"
set_property(TARGET opencv_photo APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(opencv_photo PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libopencv_photo.so.4.10.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libopencv_photo.so.410"
  )

list(APPEND _cmake_import_check_targets opencv_photo )
list(APPEND _cmake_import_check_files_for_opencv_photo "${_IMPORT_PREFIX}/lib64/libopencv_photo.so.4.10.0" )

# Import target "opencv_dnn" for configuration "RelWithDebInfo"
set_property(TARGET opencv_dnn APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(opencv_dnn PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "protobuf::libprotobuf"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libopencv_dnn.so.4.10.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libopencv_dnn.so.410"
  )

list(APPEND _cmake_import_check_targets opencv_dnn )
list(APPEND _cmake_import_check_files_for_opencv_dnn "${_IMPORT_PREFIX}/lib64/libopencv_dnn.so.4.10.0" )

# Import target "opencv_features2d" for configuration "RelWithDebInfo"
set_property(TARGET opencv_features2d APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(opencv_features2d PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libopencv_features2d.so.4.10.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libopencv_features2d.so.410"
  )

list(APPEND _cmake_import_check_targets opencv_features2d )
list(APPEND _cmake_import_check_files_for_opencv_features2d "${_IMPORT_PREFIX}/lib64/libopencv_features2d.so.4.10.0" )

# Import target "opencv_imgcodecs" for configuration "RelWithDebInfo"
set_property(TARGET opencv_imgcodecs APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(opencv_imgcodecs PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libopencv_imgcodecs.so.4.10.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libopencv_imgcodecs.so.410"
  )

list(APPEND _cmake_import_check_targets opencv_imgcodecs )
list(APPEND _cmake_import_check_files_for_opencv_imgcodecs "${_IMPORT_PREFIX}/lib64/libopencv_imgcodecs.so.4.10.0" )

# Import target "opencv_videoio" for configuration "RelWithDebInfo"
set_property(TARGET opencv_videoio APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(opencv_videoio PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libopencv_videoio.so.4.10.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libopencv_videoio.so.410"
  )

list(APPEND _cmake_import_check_targets opencv_videoio )
list(APPEND _cmake_import_check_files_for_opencv_videoio "${_IMPORT_PREFIX}/lib64/libopencv_videoio.so.4.10.0" )

# Import target "opencv_calib3d" for configuration "RelWithDebInfo"
set_property(TARGET opencv_calib3d APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(opencv_calib3d PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libopencv_calib3d.so.4.10.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libopencv_calib3d.so.410"
  )

list(APPEND _cmake_import_check_targets opencv_calib3d )
list(APPEND _cmake_import_check_files_for_opencv_calib3d "${_IMPORT_PREFIX}/lib64/libopencv_calib3d.so.4.10.0" )

# Import target "opencv_highgui" for configuration "RelWithDebInfo"
set_property(TARGET opencv_highgui APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(opencv_highgui PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libopencv_highgui.so.4.10.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libopencv_highgui.so.410"
  )

list(APPEND _cmake_import_check_targets opencv_highgui )
list(APPEND _cmake_import_check_files_for_opencv_highgui "${_IMPORT_PREFIX}/lib64/libopencv_highgui.so.4.10.0" )

# Import target "opencv_objdetect" for configuration "RelWithDebInfo"
set_property(TARGET opencv_objdetect APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(opencv_objdetect PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libopencv_objdetect.so.4.10.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libopencv_objdetect.so.410"
  )

list(APPEND _cmake_import_check_targets opencv_objdetect )
list(APPEND _cmake_import_check_files_for_opencv_objdetect "${_IMPORT_PREFIX}/lib64/libopencv_objdetect.so.4.10.0" )

# Import target "opencv_stitching" for configuration "RelWithDebInfo"
set_property(TARGET opencv_stitching APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(opencv_stitching PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libopencv_stitching.so.4.10.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libopencv_stitching.so.410"
  )

list(APPEND _cmake_import_check_targets opencv_stitching )
list(APPEND _cmake_import_check_files_for_opencv_stitching "${_IMPORT_PREFIX}/lib64/libopencv_stitching.so.4.10.0" )

# Import target "opencv_video" for configuration "RelWithDebInfo"
set_property(TARGET opencv_video APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(opencv_video PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libopencv_video.so.4.10.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libopencv_video.so.410"
  )

list(APPEND _cmake_import_check_targets opencv_video )
list(APPEND _cmake_import_check_files_for_opencv_video "${_IMPORT_PREFIX}/lib64/libopencv_video.so.4.10.0" )

# Import target "opencv_gapi" for configuration "RelWithDebInfo"
set_property(TARGET opencv_gapi APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(opencv_gapi PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libopencv_gapi.so.4.10.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libopencv_gapi.so.410"
  )

list(APPEND _cmake_import_check_targets opencv_gapi )
list(APPEND _cmake_import_check_files_for_opencv_gapi "${_IMPORT_PREFIX}/lib64/libopencv_gapi.so.4.10.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> opencv-4.10.0-18.gpkg.tar: image/usr/lib64/cmake/opencv4/OpenCVModules-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "opencv_core" for configuration "RelWithDebInfo"
set_property(TARGET opencv_core APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(opencv_core PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libopencv_core.so.4.10.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libopencv_core.so.410"
  )

list(APPEND _cmake_import_check_targets opencv_core )
list(APPEND _cmake_import_check_files_for_opencv_core "${_IMPORT_PREFIX}/lib64/libopencv_core.so.4.10.0" )

# Import target "opencv_flann" for configuration "RelWithDebInfo"
set_property(TARGET opencv_flann APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(opencv_flann PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libopencv_flann.so.4.10.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libopencv_flann.so.410"
  )

list(APPEND _cmake_import_check_targets opencv_flann )
list(APPEND _cmake_import_check_files_for_opencv_flann "${_IMPORT_PREFIX}/lib64/libopencv_flann.so.4.10.0" )

# Import target "opencv_imgproc" for configuration "RelWithDebInfo"
set_property(TARGET opencv_imgproc APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(opencv_imgproc PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libopencv_imgproc.so.4.10.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libopencv_imgproc.so.410"
  )

list(APPEND _cmake_import_check_targets opencv_imgproc )
list(APPEND _cmake_import_check_files_for_opencv_imgproc "${_IMPORT_PREFIX}/lib64/libopencv_imgproc.so.4.10.0" )

# Import target "opencv_ml" for configuration "RelWithDebInfo"
set_property(TARGET opencv_ml APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(opencv_ml PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libopencv_ml.so.4.10.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libopencv_ml.so.410"
  )

list(APPEND _cmake_import_check_targets opencv_ml )
list(APPEND _cmake_import_check_files_for_opencv_ml "${_IMPORT_PREFIX}/lib64/libopencv_ml.so.4.10.0" )

# Import target "opencv_photo" for configuration "RelWithDebInfo"
set_property(TARGET opencv_photo APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(opencv_photo PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libopencv_photo.so.4.10.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libopencv_photo.so.410"
  )

list(APPEND _cmake_import_check_targets opencv_photo )
list(APPEND _cmake_import_check_files_for_opencv_photo "${_IMPORT_PREFIX}/lib64/libopencv_photo.so.4.10.0" )

# Import target "opencv_dnn" for configuration "RelWithDebInfo"
set_property(TARGET opencv_dnn APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(opencv_dnn PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "protobuf::libprotobuf"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libopencv_dnn.so.4.10.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libopencv_dnn.so.410"
  )

list(APPEND _cmake_import_check_targets opencv_dnn )
list(APPEND _cmake_import_check_files_for_opencv_dnn "${_IMPORT_PREFIX}/lib64/libopencv_dnn.so.4.10.0" )

# Import target "opencv_features2d" for configuration "RelWithDebInfo"
set_property(TARGET opencv_features2d APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(opencv_features2d PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libopencv_features2d.so.4.10.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libopencv_features2d.so.410"
  )

list(APPEND _cmake_import_check_targets opencv_features2d )
list(APPEND _cmake_import_check_files_for_opencv_features2d "${_IMPORT_PREFIX}/lib64/libopencv_features2d.so.4.10.0" )

# Import target "opencv_imgcodecs" for configuration "RelWithDebInfo"
set_property(TARGET opencv_imgcodecs APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(opencv_imgcodecs PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libopencv_imgcodecs.so.4.10.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libopencv_imgcodecs.so.410"
  )

list(APPEND _cmake_import_check_targets opencv_imgcodecs )
list(APPEND _cmake_import_check_files_for_opencv_imgcodecs "${_IMPORT_PREFIX}/lib64/libopencv_imgcodecs.so.4.10.0" )

# Import target "opencv_videoio" for configuration "RelWithDebInfo"
set_property(TARGET opencv_videoio APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(opencv_videoio PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libopencv_videoio.so.4.10.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libopencv_videoio.so.410"
  )

list(APPEND _cmake_import_check_targets opencv_videoio )
list(APPEND _cmake_import_check_files_for_opencv_videoio "${_IMPORT_PREFIX}/lib64/libopencv_videoio.so.4.10.0" )

# Import target "opencv_calib3d" for configuration "RelWithDebInfo"
set_property(TARGET opencv_calib3d APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(opencv_calib3d PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libopencv_calib3d.so.4.10.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libopencv_calib3d.so.410"
  )

list(APPEND _cmake_import_check_targets opencv_calib3d )
list(APPEND _cmake_import_check_files_for_opencv_calib3d "${_IMPORT_PREFIX}/lib64/libopencv_calib3d.so.4.10.0" )

# Import target "opencv_highgui" for configuration "RelWithDebInfo"
set_property(TARGET opencv_highgui APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(opencv_highgui PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "Qt6::Core;Qt6::Gui;Qt6::Widgets;Qt6::Test;Qt6::Concurrent;Qt6::OpenGLWidgets;Qt6::OpenGL"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libopencv_highgui.so.4.10.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libopencv_highgui.so.410"
  )

list(APPEND _cmake_import_check_targets opencv_highgui )
list(APPEND _cmake_import_check_files_for_opencv_highgui "${_IMPORT_PREFIX}/lib64/libopencv_highgui.so.4.10.0" )

# Import target "opencv_objdetect" for configuration "RelWithDebInfo"
set_property(TARGET opencv_objdetect APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(opencv_objdetect PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libopencv_objdetect.so.4.10.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libopencv_objdetect.so.410"
  )

list(APPEND _cmake_import_check_targets opencv_objdetect )
list(APPEND _cmake_import_check_files_for_opencv_objdetect "${_IMPORT_PREFIX}/lib64/libopencv_objdetect.so.4.10.0" )

# Import target "opencv_stitching" for configuration "RelWithDebInfo"
set_property(TARGET opencv_stitching APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(opencv_stitching PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libopencv_stitching.so.4.10.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libopencv_stitching.so.410"
  )

list(APPEND _cmake_import_check_targets opencv_stitching )
list(APPEND _cmake_import_check_files_for_opencv_stitching "${_IMPORT_PREFIX}/lib64/libopencv_stitching.so.4.10.0" )

# Import target "opencv_video" for configuration "RelWithDebInfo"
set_property(TARGET opencv_video APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(opencv_video PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libopencv_video.so.4.10.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libopencv_video.so.410"
  )

list(APPEND _cmake_import_check_targets opencv_video )
list(APPEND _cmake_import_check_files_for_opencv_video "${_IMPORT_PREFIX}/lib64/libopencv_video.so.4.10.0" )

# Import target "opencv_gapi" for configuration "RelWithDebInfo"
set_property(TARGET opencv_gapi APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(opencv_gapi PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libopencv_gapi.so.4.10.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libopencv_gapi.so.410"
  )

list(APPEND _cmake_import_check_targets opencv_gapi )
list(APPEND _cmake_import_check_files_for_opencv_gapi "${_IMPORT_PREFIX}/lib64/libopencv_gapi.so.4.10.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
